# TODO: This is an example file which you should delete/edit after implementing
import os
from database_mysql_local.generic_crud import GenericCRUD
from logger_local.MetaLogger import MetaLogger
from translate import Translator
from api_management_local.api_limit import APILimitsLocal

#from language_remote import LangCode
# from python_sdk_remote.utilities import our_get_env

# The old way without class
# from .constants_src_examples_local import (<THE_ENTITIES>_CODE_LOGGER_OBJECT,
#                                <THE_ENTITY>_SCHEMA_NAME, <THE_ENTITY>_TABLE_NAME,
#                                <THE_ENTITY>_VIEW_NAME, <THE_ENTITY>_COLUMN_NAME)
# from .constants_src_<the_entities> import ConstantsSrc<TheEntities>

# logger = Logger.create_logger(object=ConstantsSrc<TheEntities>Local.<THE_ENTITIES>_CODE_LOGGER_OBJECT)


class Translate(GenericCRUD, metaclass=MetaLogger):
    def __init__(self, is_test_data: bool = False) -> None:
        #GenericCRUD.__init__(self, default_schema_name="translate")
        #self.logger.info("whatever you want to log "+ PACKAGE_VERSION)
        # TODO is this okay? considered magic variable or no?
        self.default_language = "en"
        self.api_type_id = None  # TODO where we get this from?
        # TODO check if this is good
        self.user_external_id = os.getenv("USER_EXTERNAL_ID", "")
        self.endpoint_url = ""  # TODO where we get this from?

    # If this is CRUD method please make sure we don't have this method
    #  functionality already in GenericCRUD and if needed wrap the GenericCRUD
    #  method
    # TODO implement functionality for document or non string translation?
    def translate_text(self, source_language: str, output_language: str, text: str) -> str:

        if Translator is None:
            raise ImportError("translate package is not installed. Install it to use translate_text.")

        if not output_language:
            output_language = self.default_language

        #detect how long string
        text_length = len(text)

        #logic to determine if simple translate or google cloud translate
        #get number of remaining google_cloud translates (total 500,000 per month I think)
        #if remaining > 450,000 or something,
            #use simple translate
        #else use cloud translate

        #if error with cloud translate
            #use simple translate
        
        
       
        #sfgfgs
        return #final_translation

    def translate_with_package(self, source_language: str, output_language: str, text: str,) -> str:
        # TODO implement
        if source_language:
            translator = Translator(from_lang=source_language, to_lang=output_language)
        else:
            translator = Translator(to_lang=output_language)
        final_translation = translator.translate(text)
        return final_translation

    def translate_with_google_cloud(self, input_text: str) -> str:
        #  TODO Implement
        return
# TODO: once done, run some auto lint formatter such as autopep8, autoflake or
#  whatever your IDE provide.



# serverless.com repo "python -m build" works without setup.py
# Should update package_dir if not using our recommended directory structure

import setuptools

# TODO: Change the PACKAGE_NAME to the package's name - Either xxx-local or
#  xxx-remote (without the -python-package suffix). Only lowercase, no
#  underlines.
# Used by pypa/gh-action-pypi-publish
# Package Name should be identical to the inner directory name
# Changing the package name here, will cause a change in the package directory
#  name as well

# PACKAGE_NAME should be singular if handling only one instance
# PACKAGE_NAME should not include the word "main"

# e.g.: queue-local, without python-package suffix
PACKAGE_NAME = "translate-remote"

package_dir = PACKAGE_NAME.replace("-", "_")
# If we need backward-compatible:
# old_package_dir = "old_package_name"

PACKAGE_DESCRIPTION = f"PyPI {PACKAGE_NAME} Python Package owned by Circlez.ai"

setuptools.setup(
    name=PACKAGE_NAME,
    # Increase this number every time you make a change you
    #  want to publish. After 0.0.9 switch to 0.0.10 and not 0.1.0
    #blah
    # version can't be 0.0.
    # If you find yourself increasing the version in more than one patch number (it might indicate there are multiple branches which you should submit their PRs before your PR)  # noqa: E501
    # TODO add the Jira Work Item (Jira Issue) number after the version i.e., 0.0.1b2432
    # TODO Add b2870 Make sure PythonVersionFile.psm1 and makec supports it
    version='0.0.1b2870',  # https://pypi.org/project/translate-remote/
    author="Circles",
    author_email="info@circlez.ai",
    description=f"{PACKAGE_DESCRIPTION}",
    # long_description=f"{description}",
    long_description =f"{PACKAGE_DESCRIPTION}"  # noqa E501
            + "JIRA Work Item: https://circles-zone.atlassian.net/browse/BU-2614"  # noqa E501
            + "GHA: https://github.com/circles-zone/logger-local-python-package/actions",  # noqa E501

    long_description_content_type='text/markdown',
    url=f"https://github.com/circles-zone/{PACKAGE_NAME}-python-package",
    # packages=[package_dir],
    # packages=[package_dir, old_package_dir],
    packages=setuptools.find_packages(),

    # I'm not sure we need package_dir
    # package_dir={package_dir: f'{package_dir}/src'},
    # TODO Unfortunately in event-main-local-restapi there are no
    #  repo-directory and no package directory (flat directory structure)
    # package_dir={package_dir: f'src'},

    # package_dir={package_dir: f'{package_dir}/src',
    #  old_package_dir: f'{package_dir}/src'},
    package_data={package_dir: ['*.py']},
    classifiers=[
        "Programming Language :: Python :: 3",
        # https://packaging.python.org/en/latest/guides/writing-pyproject-toml/#license
        # TODO Fix all repos, especially the Python templates
        # "License :: MIT AND (Apache-2.0 OR BSD-2-Clause)",
        "Operating System :: OS Independent",
    ],
    # Do not add packages needed only for tests i.e. packages for get_test_xxx(
    # TODO: Update which packages to include with this package in production
    #  (dependencies) - Not for development/testing
    install_requires=[
        'python-sdk-remote',
        'translate',
        # TODO: in -remote package, please use logger-remote instead.
        'logger-local',
        # TODO: In -local package please uncomment the bellow line. In -remote packages please delete this line.  # noqa E501
        # 'smart-datastore-local',
        # 'logzio-python-handler>=4.1.2',  # https://pypi.org/project/logzio-python-handler/  # noqa E501
    ]
)
